==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/AssemblyException.h <==
// class gnu.java.beans.decoder.AssemblyException

// class file dependencies
// @dep_class 4d6bfc12b6144ae0 gnu_java_beans_decoder_AssemblyException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_gnu_java_beans_decoder_AssemblyException_H_
#define _JC_gnu_java_beans_decoder_AssemblyException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_AssemblyException$sub_refs	_jc_gnu_java_beans_decoder_AssemblyException$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_AssemblyException$sub_nonrefs	_jc_gnu_java_beans_decoder_AssemblyException$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AssemblyException$refs	_jc_gnu_java_beans_decoder_AssemblyException$refs;
typedef struct _jc_gnu_java_beans_decoder_AssemblyException$nonrefs	_jc_gnu_java_beans_decoder_AssemblyException$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AssemblyException$object	_jc_gnu_java_beans_decoder_AssemblyException$object;

typedef const struct _jc_gnu_java_beans_decoder_AssemblyException$vmethods	_jc_gnu_java_beans_decoder_AssemblyException$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_AssemblyException$vtable	_jc_gnu_java_beans_decoder_AssemblyException$vtable;
typedef const struct _jc_gnu_java_beans_decoder_AssemblyException$vtype	_jc_gnu_java_beans_decoder_AssemblyException$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_AssemblyException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_gnu_java_beans_decoder_AssemblyException$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_AssemblyException$vmethods {
};

// Vtable
struct _jc_gnu_java_beans_decoder_AssemblyException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_gnu_java_beans_decoder_AssemblyException$vmethods	gnu_java_beans_decoder_AssemblyException;
};

// Vtype
struct _jc_gnu_java_beans_decoder_AssemblyException$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_AssemblyException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AssemblyException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AssemblyException$refs {
    _jc_gnu_java_beans_decoder_AssemblyException$sub_refs	gnu_java_beans_decoder_AssemblyException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AssemblyException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AssemblyException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_gnu_java_beans_decoder_AssemblyException$sub_nonrefs	gnu_java_beans_decoder_AssemblyException;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_AssemblyException$object {
	_jc_gnu_java_beans_decoder_AssemblyException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_AssemblyException$vtype	*vtype;
	_jc_gnu_java_beans_decoder_AssemblyException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_AssemblyException$vtype _jc_gnu_java_beans_decoder_AssemblyException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_AssemblyException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_AssemblyException$class_object;

#endif	/* _JC_gnu_java_beans_decoder_AssemblyException_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/AssemblyException.h <==
// class gnu.java.beans.decoder.AssemblyException

// class file dependencies
// @dep_class 4d6bfc12b6144ae0 gnu_java_beans_decoder_AssemblyException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_gnu_java_beans_decoder_AssemblyException_H_
#define _JC_gnu_java_beans_decoder_AssemblyException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_AssemblyException$sub_refs	_jc_gnu_java_beans_decoder_AssemblyException$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_AssemblyException$sub_nonrefs	_jc_gnu_java_beans_decoder_AssemblyException$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AssemblyException$refs	_jc_gnu_java_beans_decoder_AssemblyException$refs;
typedef struct _jc_gnu_java_beans_decoder_AssemblyException$nonrefs	_jc_gnu_java_beans_decoder_AssemblyException$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AssemblyException$object	_jc_gnu_java_beans_decoder_AssemblyException$object;

typedef const struct _jc_gnu_java_beans_decoder_AssemblyException$vmethods	_jc_gnu_java_beans_decoder_AssemblyException$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_AssemblyException$vtable	_jc_gnu_java_beans_decoder_AssemblyException$vtable;
typedef const struct _jc_gnu_java_beans_decoder_AssemblyException$vtype	_jc_gnu_java_beans_decoder_AssemblyException$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_AssemblyException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_gnu_java_beans_decoder_AssemblyException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_AssemblyException$vmethods {
};

// Vtable
struct _jc_gnu_java_beans_decoder_AssemblyException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_gnu_java_beans_decoder_AssemblyException$vmethods	gnu_java_beans_decoder_AssemblyException;
};

// Vtype
struct _jc_gnu_java_beans_decoder_AssemblyException$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_AssemblyException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AssemblyException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AssemblyException$refs {
    _jc_gnu_java_beans_decoder_AssemblyException$sub_refs	gnu_java_beans_decoder_AssemblyException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AssemblyException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AssemblyException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_gnu_java_beans_decoder_AssemblyException$sub_nonrefs	gnu_java_beans_decoder_AssemblyException;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_AssemblyException$object {
	_jc_gnu_java_beans_decoder_AssemblyException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_AssemblyException$vtype	*vtype;
	_jc_gnu_java_beans_decoder_AssemblyException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_AssemblyException$vtype _jc_gnu_java_beans_decoder_AssemblyException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_AssemblyException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_AssemblyException$class_object;

#endif	/* _JC_gnu_java_beans_decoder_AssemblyException_H_ */
